#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
import argparse
import glob
import os
import shutil
import tarfile

import evlasciencedatamodel as sc
import NGASUtil as ng
import persistmetadata as pm
from lxml import objectify as obj
from persistcaltables import persistcalibrations
from pycapo import CapoConfig

# TODO incorporate this in as an option of archive.py ?
# Capofy the location of the temporary location for tar unpacking
# No manifest file?


def main():
    parser = argparse.ArgumentParser(description="Ingest Calibration Tables")
    parser.add_argument("-f", "--file", help="Calibration File")
    args = parser.parse_args()

    capoprofile = os.environ["CAPO_PROFILE"]
    config = CapoConfig(profile=capoprofile)
    calibrationtablepath = config.getstring("archive-ingestion.CalibrationTablePath")

    if args.file is None:
        tarfiles = glob.glob(calibrationtablepath + "/*.tar")
    else:
        tarfiles = []
        tarfiles.append(os.path.join(calibrationtablepath, args.file))
    print("{} calibration file(s) to be archived".format(len(tarfiles)))
    calcount = 0
    calibrationfiles = []
    for calfile in tarfiles:
        print("Tar file to be ingested: {}".format(tarfile))
        calcount += 1
        calibrationfiles.append(calfile)

    ng.archivefiles(calibrationfiles)
    print("Total of {} calibrations(s) ingested".format(calcount))
    persistcalibrations(calibrationfiles)


if __name__ == "__main__":
    # Do the argparse thing
    main()
