/*
 * Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */
import { Pipe, PipeTransform } from '@angular/core';

@Pipe({
  name: 'frequency'
})
export class FrequencyPipe implements PipeTransform {

  transform(value: any, precision?: number): any {
    const extensions = ['', 'kHz', 'MHz', 'GHz', 'THz', 'PHz', 'EHz', 'ZHz', 'YHz'];

    let size = parseInt(value);
    const scale = Math.floor(Math.log(size) / Math.log(10) / 3.0);

    if (!value || isNaN(size)) {
      return value;
    }
    if (precision === undefined ||isNaN(precision)){
      precision = 7;
    }

    if (scale === 0) {
      return size;
    }

    let reduced = size / (Math.pow(10, scale*3));

    return reduced.toFixed(precision) + ' ' + extensions[scale];
  }

}
