#
# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
from datetime import datetime

from immutable_views import DictView

from workspaces.system.views import ViewWorkflowCapoParameters
from workspaces.workflow.schema import Workflow, WorkflowRequest

"""
tests for views.ViewWorkflowCapoParameters
"""
expected_list = DictView(
    {
        "general": [
            "edu.nrao.workspaces.WorkflowSettings.serviceUrl",
            "edu.nrao.workspaces.NotificationSettings.serviceUrl",
            "edu.nrao.workspaces.UISettings.serviceUrl",
        ],
        "casa_requirements": [
            "edu.nrao.workspaces.ProcessingSettings.useCasa",
            "edu.nrao.workspaces.ProcessingSettings.CasaVersion.vlass",
            "edu.nrao.archive.workflow.config.CasaVersions.homeForReprocessing",
        ],
    }
)

request = WorkflowRequest(
    workflow_request_id=-3,
    workflow=Workflow(workflow_name="vlass_seci", uses_casa=True),
    workflow_name="vlass_seci",
    argument={},
    state="Created",
    created_at=datetime(2021, 1, 1),
    updated_at=datetime(2021, 1, 1),
)
view = ViewWorkflowCapoParameters(request)


class TestViewWorkflowCapoParameters:
    def test_general_parameters(self):
        general_params = view.general_parameters()
        assert general_params == expected_list["general"]

    def test_casa_parameters(self):
        casa_params = view.casa_parameters()
        assert casa_params == expected_list["casa_requirements"]

    def test_construct_view(self):
        constructed_view = view.construct_view()
        assert constructed_view == [
            "edu.nrao.workspaces.WorkflowSettings.serviceUrl",
            "edu.nrao.workspaces.NotificationSettings.serviceUrl",
            "edu.nrao.workspaces.UISettings.serviceUrl",
            "edu.nrao.workspaces.ProcessingSettings.useCasa",
            "edu.nrao.workspaces.ProcessingSettings.CasaVersion.vlass",
            "edu.nrao.archive.workflow.config.CasaVersions.homeForReprocessing",
        ]
